==> activity-center-biz-1.0.2-20160622.061036-30-sources.jar: cn/com/duiba/activity/center/biz/service/quizz/impl/DuibaQuizzBrickServiceImpl.java <==
package cn.com.duiba.activity.center.biz.service.quizz.impl;

import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.quizz.DuibaQuizzBrickDto;
import cn.com.duiba.activity.center.biz.dao.quizz.DuibaQuizzBrickDao;
import cn.com.duiba.activity.center.biz.entity.quizz.DuibaQuizzBrickEntity;
import cn.com.duiba.activity.center.biz.service.quizz.DuibaQuizzBrickService;
import cn.com.duiba.wolf.utils.BeanUtils;

import com.google.common.base.Preconditions;

/**
 * Created by xuezhaoming on 16/6/8.
 */
@Service
public class DuibaQuizzBrickServiceImpl implements DuibaQuizzBrickService {

    @Resource
    private DuibaQuizzBrickDao duibaQuizzBrickDao;

    @Override
    public DuibaQuizzBrickDto find(Long id) {
        Preconditions.checkNotNull(id, "id is null");
        return BeanUtils.copy(duibaQuizzBrickDao.find(id), DuibaQuizzBrickDto.class);
    }

    @Override
    public String getBrickContentById(Long id) {

        Preconditions.checkNotNull(id, "id is null");
        return duibaQuizzBrickDao.getBrickContentById(id);
    }

    @Override
    public DuibaQuizzBrickDto findNoContent(Long id) {
        Preconditions.checkNotNull(id, "id is null");
        return BeanUtils.copy(duibaQuizzBrickDao.findNoContent(id), DuibaQuizzBrickDto.class);
    }

	@Override
	public void insert(DuibaQuizzBrickDto duibaQuestionAnswerBrick) {
		duibaQuizzBrickDao.insert(BeanUtils.copy(duibaQuestionAnswerBrick, DuibaQuizzBrickEntity.class));
	}

	@Override
	public void update4Admin(Long id, String title, String content, String md5) {
		duibaQuizzBrickDao.update4Admin(id, title, content, md5);
	}

	@Override
	public DuibaQuizzBrickDto findByTitle(String title) {
		return BeanUtils.copy(duibaQuizzBrickDao.findByTitle(title), DuibaQuizzBrickDto.class);
	}

	@Override
	public void open(Long id) {
		duibaQuizzBrickDao.open(id);
	}

	@Override
	public void disable(Long id) {
		duibaQuizzBrickDao.disable(id);
	}

	@Override
	public List<DuibaQuizzBrickDto> findPage(Map<String, Object> queryMap) {
		return BeanUtils.copyList(duibaQuizzBrickDao.findPage(queryMap), DuibaQuizzBrickDto.class);
	}

	@Override
	public Long findPageCount() {
		return duibaQuizzBrickDao.findPageCount();
	}

	@Override
	public List<DuibaQuizzBrickDto> findAll() {
		return BeanUtils.copyList(duibaQuizzBrickDao.findAll(), DuibaQuizzBrickDto.class);
	}
}

==> activity-center-biz-1.0.2-20160706.034119-56-sources.jar: cn/com/duiba/activity/center/biz/service/quizz/impl/DuibaQuizzBrickServiceImpl.java <==
package cn.com.duiba.activity.center.biz.service.quizz.impl;

import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.quizz.DuibaQuizzBrickDto;
import cn.com.duiba.activity.center.biz.dao.quizz.DuibaQuizzBrickDao;
import cn.com.duiba.activity.center.biz.entity.quizz.DuibaQuizzBrickEntity;
import cn.com.duiba.activity.center.biz.service.quizz.DuibaQuizzBrickService;
import cn.com.duiba.wolf.utils.BeanUtils;

import com.google.common.base.Preconditions;

/**
 * Created by xuezhaoming on 16/6/8.
 */
@Service
public class DuibaQuizzBrickServiceImpl implements DuibaQuizzBrickService {

    @Resource
    private DuibaQuizzBrickDao duibaQuizzBrickDao;

    @Override
    public DuibaQuizzBrickDto find(Long id) {
        Preconditions.checkNotNull(id, "id is null");
        return BeanUtils.copy(duibaQuizzBrickDao.find(id), DuibaQuizzBrickDto.class);
    }

    @Override
    public String getBrickContentById(Long id) {

        Preconditions.checkNotNull(id, "id is null");
        return duibaQuizzBrickDao.getBrickContentById(id);
    }

    @Override
    public DuibaQuizzBrickDto findNoContent(Long id) {
        Preconditions.checkNotNull(id, "id is null");
        return BeanUtils.copy(duibaQuizzBrickDao.findNoContent(id), DuibaQuizzBrickDto.class);
    }

	@Override
	public void insert(DuibaQuizzBrickDto duibaQuestionAnswerBrick) {
		DuibaQuizzBrickEntity entity = BeanUtils.copy(duibaQuestionAnswerBrick, DuibaQuizzBrickEntity.class);
		duibaQuizzBrickDao.insert(entity);
		duibaQuestionAnswerBrick.setId(entity.getId());
	}

	@Override
	public void update4Admin(Long id, String title, String content, String md5) {
		duibaQuizzBrickDao.update4Admin(id, title, content, md5);
	}

	@Override
	public DuibaQuizzBrickDto findByTitle(String title) {
		return BeanUtils.copy(duibaQuizzBrickDao.findByTitle(title), DuibaQuizzBrickDto.class);
	}

	@Override
	public void open(Long id) {
		duibaQuizzBrickDao.open(id);
	}

	@Override
	public void disable(Long id) {
		duibaQuizzBrickDao.disable(id);
	}

	@Override
	public List<DuibaQuizzBrickDto> findPage(Map<String, Object> queryMap) {
		return BeanUtils.copyList(duibaQuizzBrickDao.findPage(queryMap), DuibaQuizzBrickDto.class);
	}

	@Override
	public Long findPageCount() {
		return duibaQuizzBrickDao.findPageCount();
	}

	@Override
	public List<DuibaQuizzBrickDto> findAll() {
		return BeanUtils.copyList(duibaQuizzBrickDao.findAll(), DuibaQuizzBrickDto.class);
	}
}
